@@ -34,8 +34,6 @@
 #define GTK_DISABLE_DEPRECATED
 #define GNOME_DISABLE_DEPRECATED
 
-#include <gnome.h>
-
 #ifdef __cplusplus
 extern "C" {
 #pragma }
@@ -89,10 +87,12 @@ struct _InterfaceStruct {
 	GtkWidget		*stop_button;
 	GtkWidget 		*save_button;
 	GtkWidget 		*main_window;	
+	GtkWidget		*table;	
 	GtkWidget 		*file_selector;
 	GtkWidget 		*status_bar;
 	GtkWidget   		*progress_bar;
 	GtkWidget	 	*disclosure;
+	GtkWidget		*add_button;
 	GtkWidget 		*additional_constraints;
 	GtkWidget		*constraint_menu;
 	GtkWidget 		*constraint;
@@ -136,6 +136,9 @@ remove_constraint 		(gint constraint_id);
 void  		
 update_constraint_info 		(SearchConstraint *constraint, 
 				 gchar *info);
+void
+set_constraint_selected_state	(gint		constraint_id, 
+				 gboolean	state);
 gboolean
 update_progress_bar 		(gpointer data);
 
