@@ -75,6 +75,7 @@ void CloseAllLogs (void);
 
 static void toggle_calendar (void);
 static void toggle_zoom (void);
+static void toggle_collapse_rows (void);
 
 /*
  *    ,-------.
@@ -147,6 +148,13 @@ GnomeUIInfo view_menu[] = {
 				NULL, 
 				GNOME_APP_PIXMAP_NONE, NULL, 
 				'D', GDK_CONTROL_MASK, NULL },
+	{ GNOME_APP_UI_ITEM, N_("_Collapse All"),
+				N_("Collapse all the rows"),
+				toggle_collapse_rows,
+				NULL,
+				NULL,
+				GNOME_APP_PIXMAP_NONE, NULL, 
+				'C', GDK_CONTROL_MASK, NULL },
 	GNOMEUIINFO_END
 };
 
@@ -428,7 +436,7 @@ CreateMainWin ()
    /* Add Tree View Columns */
    for (i = 0; column_titles[i]; i++) {
         renderer = gtk_cell_renderer_text_new ();
-        column = gtk_tree_view_column_new_with_attributes (column_titles[i],
+        column = gtk_tree_view_column_new_with_attributes (_(column_titles[i]),
                     renderer, "text", i, NULL);
         gtk_tree_view_column_set_sizing (column, GTK_TREE_VIEW_COLUMN_AUTOSIZE); 
         gtk_tree_view_column_set_resizable (column, TRUE);
@@ -587,6 +595,7 @@ FileSelectOk (GtkWidget * w, GtkFileSelection * fs)
            
 	       curlog = tl;
 	       curlog->first_time = TRUE; 
+	       curlog->mon_on = FALSE;
 		   loglist[numlogs] = tl;
 		   numlogs++;
 		   curlognum = numlogs - 1;
@@ -868,10 +877,12 @@ void SetDefaultUserPrefs(UserPrefsStruct *prefs)
 			prefs->logfile = g_strdup ("/var/adm/messages");
 		else if (lstat("/var/log/messages", &filestat) == 0) 
 			prefs->logfile = g_strdup ("/var/log/messages");
+		else if (lstat("/var/log/sys.log", &filestat) == 0) 
+			prefs->logfile = g_strdup ("/var/log/sys.log");
 		else
 			prefs->logfile = NULL;
 	}
-	
+	g_free (logfile);	
 }
 
 void SaveUserPrefs(UserPrefsStruct *prefs)
@@ -900,3 +911,9 @@ toggle_zoom (void)
 	create_zoom_view ();
 
 }
+
+static void 
+toggle_collapse_rows (void)
+{
+    gtk_tree_view_collapse_all (GTK_TREE_VIEW (view));
+}
